@@ -10,4 +10,4 @@ class Deletable[I = str](abc.ABC):
 
 class AsyncDeletable[I = str](abc.ABC):
     @abc.abstractmethod
-    async def delete(self, uid: I) -> None: ...
+    async def delete_async(self, uid: I) -> None: ...
