@@ -9,4 +9,4 @@ class Updatable[T = Any, I = str](abc.ABC):
 
 
 class AsyncUpdatable[T = Any, I = str](abc.ABC):
-    async def update(self, uid: I, new: T) -> None: ...
+    async def update_async(self, uid: I, new: T) -> None: ...
