@@ -10,4 +10,4 @@ class Writable[T](abc.ABC):
 
 class AsyncWritable[T](abc.ABC):
     @abc.abstractmethod
-    async def write(self, e: T) -> None: ...
+    async def write_async(self, e: T) -> None: ...
